@@ -1,6 +1,6 @@
 #################################################################################
 ##
-##   R package rugarch by Alexios Ghalanos Copyright (C) 2008-2015.
+##   R package rugarch by Alexios Galanos Copyright (C) 2008-2022.
 ##   This file is part of the R package rugarch.
 ##
 ##   The R package rugarch is free software: you can redistribute it and/or modify
@@ -26,8 +26,8 @@
 			nlminb = .nlminbsolver(pars, fun, gr, hessian, parscale, control, LB, UB, arglist),
 			solnp = .solnpsolver(pars, fun, Ifn, ILB, IUB, control, LB, UB, arglist),
 			gosolnp = .gosolnpsolver(pars, fun, Ifn, ILB, IUB, gocontrol, LB, UB, arglist),
-			lbfgs = .lbfgssolver(pars, fun, gr, parscale, control, LB, UB, arglist),
-			nloptr = .nloptrsolver(pars, fun, control, LB, UB, arglist))
+			lbfgs = .lbfgssolver(pars, fun, gr, parscale, control, LB, UB, arglist))
+			#nloptr = .nloptrsolver(pars, fun, control, LB, UB, arglist))
 	return(retval)
 }
 
@@ -77,9 +77,9 @@
 			if(xcontrol$trace) cat("\nTrying gosolnp solver...\n")
 			ans = .gosolnpsolver(pars, fun, Ifn, ILB, IUB, control, LB, UB, arglist)
 			if(ans$sol$convergence>=1){
-				xcontrol = .getcontrol("nloptr", control)
-				if(xcontrol$print_level) cat("\nLast try...nloptr solver...\n")
-				ans = .nloptrsolver(pars, fun, xcontrol, LB, UB, arglist = arglist)
+				# xcontrol = .getcontrol("nloptr", control)
+				if(xcontrol$trace) cat("\nTrying gosolnp solver...\n")
+				ans = .gosolnpsolver(pars, fun, Ifn, ILB, IUB, control, LB, UB, arglist)
 			}
 		}
 	}
@@ -154,26 +154,26 @@
 }
 
 # nloptr solver requires named (...)!
-.nloptrsolver = function(pars, fun, control, LB, UB, arglist){
-	ans = try(nloptr(x0 = pars, eval_f = fun,  eval_grad_f = NULL,
-					eval_g_ineq = NULL, lb = LB, ub = UB, eval_jac_g_ineq = NULL,
-					eval_g_eq = NULL, eval_jac_g_eq = NULL, opts = control, arglist = arglist),
-			silent=TRUE)
-	if(inherits(ans, "try-error")){
-		sol = list()
-		sol$convergence = 1
-		sol$message = ans
-		sol$par = rep(NA, length(pars))
-		names(sol$par) = names(pars)
-	} else{
-		sol = list()
-		sol$convergence = 0
-		sol$message = ans$message
-		sol$par = ans$solution
-	}
-	hess = NULL
-	return(list(sol = sol, hess = hess))
-}
+# .nloptrsolver = function(pars, fun, control, LB, UB, arglist){
+# 	ans = try(nloptr(x0 = pars, eval_f = fun,  eval_grad_f = NULL,
+# 					eval_g_ineq = NULL, lb = LB, ub = UB, eval_jac_g_ineq = NULL,
+# 					eval_g_eq = NULL, eval_jac_g_eq = NULL, opts = control, arglist = arglist),
+# 			silent=TRUE)
+# 	if(inherits(ans, "try-error")){
+# 		sol = list()
+# 		sol$convergence = 1
+# 		sol$message = ans
+# 		sol$par = rep(NA, length(pars))
+# 		names(sol$par) = names(pars)
+# 	} else{
+# 		sol = list()
+# 		sol$convergence = 0
+# 		sol$message = ans$message
+# 		sol$par = ans$solution
+# 	}
+# 	hess = NULL
+# 	return(list(sol = sol, hess = hess))
+# }
 
 # default control for solvers:
 .getcontrol = function(solver, control)
@@ -182,8 +182,8 @@
 		nlminb = .nlminbctrl(control),
 		solnp = .solnpctrl(control),
 		gosolnp = .gosolnpctrl(control),
-		lbfgs = .lbfgsctrl(control),
-		nloptr = .nloptrctrl(control))
+		lbfgs = .lbfgsctrl(control))
+		#nloptr = .nloptrctrl(control))
 	return(ans)
 }
 
@@ -258,54 +258,54 @@
 	}
 	return(ans)
 }
-
-.nloptrctrl = function(control){
-	#solver = c("NLOPT_LN_COBYLA", "NLOPT_LN_BOBYQA", "NLOPT_LN_PRAXIS", "NLOPT_LN_NELDERMEAD", "NLOPT_LN_SBPLX",
-	# and AUGLAG + solver
-	# subsolvers:
-	xsub = c("NLOPT_LN_COBYLA", "NLOPT_LN_BOBYQA", "NLOPT_LN_PRAXIS", "NLOPT_LN_NELDERMEAD", "NLOPT_LN_SBPLX")
-	ans = list()
-	params = unlist(control)
-	if(is.null(params)) {
-		ans$ftol_rel = 1e-8
-		ans$xtol_rel = 1e-6
-		ans$maxeval = 25000
-		ans$print_level = 0
-		mainsolver = "NLOPT_LN_SBPLX"
-		subsolver = NULL
-	} else{
-		npar = tolower(names(unlist(control)))
-		names(params) = npar
-		if(any(substr(npar, 1, 8) == "ftol_rel")) ans$ftol_rel = as.numeric(params["ftol_rel"]) else ans$ftol_rel = 1e-8
-		if(any(substr(npar, 1, 8) == "xtol_rel")) ans$xtol_rel = as.numeric(params["xtol_rel"]) else ans$xtol_rel = 1e-6
-		if(any(substr(npar, 1, 7) == "maxeval")) ans$maxeval = as.numeric(params["maxeval"]) else ans$maxeval = 25000
-		if(any(substr(npar, 1, 11) == "print_level")) ans$print_level = as.numeric(params["print_level"]) else ans$print_level = 0
-		if(any(substr(npar, 1, 6) == "solver")){
-			if(abs(as.integer(params["solver"]))>5){
-				mainsolver = "NLOPT_LN_AUGLAG"
-				subsolver = xsub[min(5,abs(as.integer(params["solver"]))-5 )]
-			} else{
-				mainsolver = xsub[min(5,abs(as.integer(params["solver"])))]
-				subsolver = NULL
-			}
-		} else{
-			mainsolver = "NLOPT_LN_SBPLX"
-			subsolver = NULL
-		}
-	}
-	if(is.null(subsolver)){
-		ans$algorithm = mainsolver
-	} else{
-		ans$algorithm = mainsolver
-		ans$local_opts$algorithm = subsolver
-		ans$local_opts$ftol_abs = ans$ftol_rel
-		ans$local_opts$xtol_rel = ans$xtol_rel
-		ans$local_opts$maxeval = 2000
-		ans$local_opts$print_level = 0
-
-	}
-	return(ans)
-}
+# 
+# .nloptrctrl = function(control){
+# 	#solver = c("NLOPT_LN_COBYLA", "NLOPT_LN_BOBYQA", "NLOPT_LN_PRAXIS", "NLOPT_LN_NELDERMEAD", "NLOPT_LN_SBPLX",
+# 	# and AUGLAG + solver
+# 	# subsolvers:
+# 	xsub = c("NLOPT_LN_COBYLA", "NLOPT_LN_BOBYQA", "NLOPT_LN_PRAXIS", "NLOPT_LN_NELDERMEAD", "NLOPT_LN_SBPLX")
+# 	ans = list()
+# 	params = unlist(control)
+# 	if(is.null(params)) {
+# 		ans$ftol_rel = 1e-8
+# 		ans$xtol_rel = 1e-6
+# 		ans$maxeval = 25000
+# 		ans$print_level = 0
+# 		mainsolver = "NLOPT_LN_SBPLX"
+# 		subsolver = NULL
+# 	} else{
+# 		npar = tolower(names(unlist(control)))
+# 		names(params) = npar
+# 		if(any(substr(npar, 1, 8) == "ftol_rel")) ans$ftol_rel = as.numeric(params["ftol_rel"]) else ans$ftol_rel = 1e-8
+# 		if(any(substr(npar, 1, 8) == "xtol_rel")) ans$xtol_rel = as.numeric(params["xtol_rel"]) else ans$xtol_rel = 1e-6
+# 		if(any(substr(npar, 1, 7) == "maxeval")) ans$maxeval = as.numeric(params["maxeval"]) else ans$maxeval = 25000
+# 		if(any(substr(npar, 1, 11) == "print_level")) ans$print_level = as.numeric(params["print_level"]) else ans$print_level = 0
+# 		if(any(substr(npar, 1, 6) == "solver")){
+# 			if(abs(as.integer(params["solver"]))>5){
+# 				mainsolver = "NLOPT_LN_AUGLAG"
+# 				subsolver = xsub[min(5,abs(as.integer(params["solver"]))-5 )]
+# 			} else{
+# 				mainsolver = xsub[min(5,abs(as.integer(params["solver"])))]
+# 				subsolver = NULL
+# 			}
+# 		} else{
+# 			mainsolver = "NLOPT_LN_SBPLX"
+# 			subsolver = NULL
+# 		}
+# 	}
+# 	if(is.null(subsolver)){
+# 		ans$algorithm = mainsolver
+# 	} else{
+# 		ans$algorithm = mainsolver
+# 		ans$local_opts$algorithm = subsolver
+# 		ans$local_opts$ftol_abs = ans$ftol_rel
+# 		ans$local_opts$xtol_rel = ans$xtol_rel
+# 		ans$local_opts$maxeval = 2000
+# 		ans$local_opts$print_level = 0
+# 
+# 	}
+# 	return(ans)
+# }
 #----------------------------------------------------------------------------------
 .garchconbounds = function(){
 	return(list(LB = eps,UB = 0.999))
